==> tai_sql-0.1.17-py3-none-any.whl: tai_sql/generators/crud/sync/__init__.py <==
import os
import jinja2
from typing import ClassVar, Optional

from tai_sql import db
from ...base import BaseGenerator

class SyncCRUDGenerator(BaseGenerator):
    """
    Generador de clases CRUD para modelos SQLAlchemy con soporte sync/async.
    """

    _jinja_env: ClassVar[jinja2.Environment] = None
    
    def __init__(self, 
                 output_dir: Optional[str] = None, 
                 models_import_path: str = "database.models"):
        """
        Inicializa el generador CRUD.
        
        Args:
            output_dir: Directorio de salida para los archivos CRUD
            models_import_path: Ruta de importación donde están los modelos generados
        """
        super().__init__(output_dir)
        self.models_import_path = models_import_path
    
    @property
    def jinja_env(self) -> jinja2.Environment:
        """Retorna el entorno Jinja2 configurado"""
        if self._jinja_env is None:
            templates_dir = os.path.join(os.path.dirname(__file__), 'templates')
            self._jinja_env = jinja2.Environment(
                loader=jinja2.FileSystemLoader(templates_dir),
                trim_blocks=True,
                lstrip_blocks=True
            )
        return self._jinja_env
    
    def generate(self) -> str:
        """
        Genera las clases CRUD según el modo especificado.
        
        Returns:
            Ruta al directorio generado
        """
        
        # Generar session_manager.py
        self.generate_session_manager()
        
        # Generar endpoints.py
        self.generate_endpoints()
        
        # Generar __init__.py
        self.generate_init_file()

        return self.config.output_dir
    
    def generate_session_manager(self) -> None:
        """
        Genera el archivo session_manager.py
        """
        template = self.jinja_env.get_template(f'session_manager.py.jinja2')

        imports = [
            'from __future__ import annotations',
            'import os',
            'import re',
            'from urllib.parse import unquote',
            'from typing import Optional, Generator',
            'from contextlib import contextmanager',
            'from urllib.parse import urlparse, parse_qs',
            'from sqlalchemy import create_engine, Engine, URL',
            'from sqlalchemy.orm import sessionmaker, Session'
        ]
        
        code = template.render(
            imports=imports,
            provider=db.provider,
            engine_params=db.engine_params.to_dict(),
            connection_params=db.provider.get_connection_params()
        )
        
        file_path = os.path.join(self.config.output_dir, 'session_manager.py')
        with open(file_path, 'w', encoding='utf-8') as f:
            f.write(code)
    
    def generate_endpoints(self) -> None:
        """
        Genera el archivo endpoints.py
        """
        template = self.jinja_env.get_template(f'endpoints.py.jinja2')

        imports = [
            'from __future__ import annotations',
            'from dataclasses import dataclass',
            'from typing import List, Optional, Dict, Literal, Any, TYPE_CHECKING',
            'from sqlalchemy.orm import Session',
            'from sqlalchemy import select, update, delete',
            f'from {self.models_import_path} import *',
            'from .session_manager import SyncSessionManager',
            '',
            'if TYPE_CHECKING:',
            '    from pandas import DataFrame, Series  # type: ignore[import-untyped]'
        ]

        has_datetime = any(
                any(col.type == 'datetime' for col in model.columns.values())
                for model in self.models
            )
        if has_datetime:
            imports.append('from datetime import datetime')
        
        models_data = [model.info() for model in self.models]

        code = template.render(
            imports=imports,
            models=models_data,
            models_import_path=self.models_import_path,
            schema_name=db.schema
        )
        
        file_path = os.path.join(self.config.output_dir, 'endpoints.py')
        with open(file_path, 'w', encoding='utf-8') as f:
            f.write(code)
    
    def generate_init_file(self) -> None:
        """
        Genera el archivo __init__.py
        """
        template = self.jinja_env.get_template(f'__init__.py.jinja2')

        imports = [
            'from __future__ import annotations',
            'from typing import Optional',
            'from .session_manager import SyncSessionManager',
            'from .endpoints import *'
        ]
        
        crud_classes = [f"{model.info()['name']}CRUD" for model in self.models]
        
        code = template.render(
            imports=imports,
            models=self.models,
            crud_classes=crud_classes,
            models_import_path=self.models_import_path,
            mode_prefix='Sync'  # 'Sync' o 'Async'
        )
        
        file_path = os.path.join(self.config.output_dir, '__init__.py')
        with open(file_path, 'w', encoding='utf-8') as f:
            f.write(code)

==> tai_sql-0.2.8-py3-none-any.whl: tai_sql/generators/crud/sync/__init__.py <==
import os
import jinja2
from typing import ClassVar, Optional

from tai_sql import db
from ...base import BaseGenerator

class SyncCRUDGenerator(BaseGenerator):
    """
    Generador de clases CRUD para modelos SQLAlchemy con soporte sync/async.
    """

    _jinja_env: ClassVar[jinja2.Environment] = None
    
    def __init__(self, 
                 output_dir: Optional[str] = None, 
                 models_import_path: str = "database.models"):
        """
        Inicializa el generador CRUD.
        
        Args:
            output_dir: Directorio de salida para los archivos CRUD
            models_import_path: Ruta de importación donde están los modelos generados
        """
        super().__init__(output_dir)
        self.models_import_path = models_import_path
    
    @property
    def jinja_env(self) -> jinja2.Environment:
        """Retorna el entorno Jinja2 configurado"""
        if self._jinja_env is None:
            templates_dir = os.path.join(os.path.dirname(__file__), 'templates')
            self._jinja_env = jinja2.Environment(
                loader=jinja2.FileSystemLoader(templates_dir),
                trim_blocks=True,
                lstrip_blocks=True
            )
        return self._jinja_env
    
    def generate(self) -> str:
        """
        Genera las clases CRUD según el modo especificado.
        
        Returns:
            Ruta al directorio generado
        """
        
        # Generar session_manager.py
        self.generate_session_manager()
        
        # Generar endpoints.py
        self.generate_endpoints()
        
        # Generar __init__.py
        self.generate_init_file()

        return self.config.output_dir
    
    def generate_session_manager(self) -> None:
        """
        Genera el archivo session_manager.py
        """
        template = self.jinja_env.get_template(f'session_manager.py.jinja2')

        imports = [
            'from __future__ import annotations',
            'import os',
            'import re',
            'from urllib.parse import unquote',
            'from typing import Optional, Generator',
            'from contextlib import contextmanager',
            'from urllib.parse import urlparse, parse_qs',
            'from sqlalchemy import create_engine, Engine, URL',
            'from sqlalchemy.orm import sessionmaker, Session'
        ]
        
        code = template.render(
            imports=imports,
            provider=db.provider,
            engine_params=db.engine_params.to_dict(),
            connection_params=db.provider.get_connection_params()
        )
        
        file_path = os.path.join(self.config.output_dir, 'session_manager.py')
        with open(file_path, 'w', encoding='utf-8') as f:
            f.write(code)
    
    def generate_endpoints(self) -> None:
        """
        Genera el archivo endpoints.py
        """
        template = self.jinja_env.get_template(f'endpoints.py.jinja2')

        imports = [
            'from __future__ import annotations',
            'from dataclasses import dataclass',
            'from typing import List, Optional, Dict, Literal, Any, TYPE_CHECKING',
            'from sqlalchemy.orm import Session',
            'from sqlalchemy import select, update, delete',
            f'from {self.models_import_path} import *',
            'from .session_manager import SyncSessionManager',
            '',
            'if TYPE_CHECKING:',
            '    from pandas import DataFrame, Series  # type: ignore[import-untyped]'
        ]

        has_datetime = any(
                any(col.type == 'datetime' for col in model.columns.values())
                for model in self.models
            )
        if has_datetime:
            imports.append('from datetime import datetime')
        
        models_data = [model.info() for model in self.models]

        code = template.render(
            imports=imports,
            models=models_data,
            models_import_path=self.models_import_path,
            schema_name=db.schema_name
        )
        
        file_path = os.path.join(self.config.output_dir, 'endpoints.py')
        with open(file_path, 'w', encoding='utf-8') as f:
            f.write(code)
    
    def generate_init_file(self) -> None:
        """
        Genera el archivo __init__.py
        """
        template = self.jinja_env.get_template(f'__init__.py.jinja2')

        imports = [
            'from __future__ import annotations',
            'from typing import Optional',
            'from .session_manager import SyncSessionManager',
            'from .endpoints import *'
        ]
        
        crud_classes = [f"{model.info()['name']}CRUD" for model in self.models]
        
        code = template.render(
            imports=imports,
            models=self.models,
            crud_classes=crud_classes,
            models_import_path=self.models_import_path,
            mode_prefix='Sync'  # 'Sync' o 'Async'
        )
        
        file_path = os.path.join(self.config.output_dir, '__init__.py')
        with open(file_path, 'w', encoding='utf-8') as f:
            f.write(code)
